# Table of Contents

- [get-data-into-workspace](<./get-data-into-workspace.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Getting Data into Your Workspace](<./Getting-Data-into-Your-Workspace.md>)
  - [Overview](<./Getting-Data-into-Your-Workspace/Overview.md>)
  - [Best Practices for Building the Inventory](<./Getting-Data-into-Your-Workspace/Best-Practices-for-Building-the-Inventory.md>)
  - [Step 1. Upload Application Data into SAP LeanIX](<./Getting-Data-into-Your-Workspace/Step-1.-Upload-Application-Data-into-SAP-LeanIX.md>)
  - [Step 2. Define and add Business Capabilities](<./Getting-Data-into-Your-Workspace/Step-2.-Define-and-add-Business-Capabilities.md>)
  - [Step 3. Add Organizations](<./Getting-Data-into-Your-Workspace/Step-3.-Add-Organizations.md>)
  - [Step 4. Link Applications to Business Capabilities and Organizations](<./Getting-Data-into-Your-Workspace/Step-4.-Link-Applications-to-Business-Capabilities-and-Organizations.md>)
  - [Next Steps](<./Getting-Data-into-Your-Workspace/Next-Steps.md>)
  - [Was this page helpful?](<./Getting-Data-into-Your-Workspace/Was-this-page-helpful.md>)
